@@ -32,6 +32,9 @@ You're limited only by your imagination. If you can think of it and code it in P
 
 package Mail::MIMEDefang;
 
+use warnings;
+no warnings qw(once uninitialized);
+
 require Exporter;
 
 use Carp;
@@ -42,7 +45,7 @@ our @ISA = qw(Exporter);
 our @EXPORT;
 our @EXPORT_OK;
 
-our $VERSION = '3.1';
+our $VERSION = '3.2';
 
 @EXPORT = qw{
       $AddWarningsInline @StatusTags
@@ -852,7 +855,7 @@ sub send_quarantine_notifications {
 	  my($body);
 	  $body = "From: $DaemonName <$DaemonAddress>\n";
 	  $body .= "To: \"$AdminName\" <$AdminAddress>\n";
-	  $body .= gen_date_msgid_headers();
+	  $body .= Mail::MIMEDefang::RFC2822::gen_date_msgid_headers();
 	  $body .= "Auto-Submitted: auto-generated\n";
 	  $body .= "MIME-Version: 1.0\nContent-Type: text/plain\n";
 	  $body .= "Precedence: bulk\n";
@@ -865,7 +868,7 @@ sub send_quarantine_notifications {
 	  }
 
 	  $body .= " quarantined in the directory\n";
-	  $body .= "$QuarantineSubdir on " . get_host_name() . ".\n\n";
+	  $body .= "$QuarantineSubdir on " . Mail::MIMEDefang::Net::get_host_name() . ".\n\n";
 	  $body .= "The sender was '$Sender'.\n\n" if defined($Sender);
 	  $body .= "The Sendmail queue identifier was $QueueID.\n\n" if ($QueueID ne "NOQUEUE");
 	  $body .= "The relay machine was $RelayHostname ($RelayAddr).\n\n";
@@ -942,7 +945,7 @@ sub signal_complete {
 	  my($body);
 	  $body = "From: $DaemonName <$DaemonAddress>\n";
 	  $body .= "To: $Sender\n";
-	  $body .= gen_date_msgid_headers();
+	  $body .= Mail::MIMEDefang::RFC2822::gen_date_msgid_headers();
 	  $body .= "Auto-Submitted: auto-generated\n";
 	  $body .= "MIME-Version: 1.0\nContent-Type: text/plain\n";
 	  $body .= "Precedence: bulk\n";
@@ -1103,7 +1106,7 @@ sub send_admin_mail {
   my $mail;
   $mail = "From: $DaemonName <$DaemonAddress>\n";
   $mail .= "To: \"$AdminName\" <$AdminAddress>\n";
-  $mail .= gen_date_msgid_headers();
+  $mail .= Mail::MIMEDefang::RFC2822::gen_date_msgid_headers();
   $mail .= "Auto-Submitted: auto-generated\n";
   $mail .= "MIME-Version: 1.0\nContent-Type: text/plain\n";
   $mail .= "Precedence: bulk\n";
